@@ -6,6 +6,9 @@
  *
  * Revisions:
  *
+ * 07/12/09  [rcg]
+ *         - Stop using sys_nerr and sys_errlist.
+ *
  * 03/09/01  [rcg]
  *         - Now including continuation of UIDL headers in UIDL hash.
  *         - Don't include random component of extra headers in UIDL
@@ -1289,7 +1292,7 @@ struct passwd   * pwp;
         if ( p->bull_db == NULL ) {
             pop_log (p, POP_PRIORITY, HERE, "gdbm_open failed: %s (%d)"
                                             "; bull_db: %s",
-                        sys_errlist[errno], errno, bull_db );
+                        STRERROR( errno ), errno, bull_db );
             if ( p->bulldb_nonfatal == FALSE )
                 return ( pop_msg ( p, POP_FAILURE, HERE, 
                                    "[SYS/TEMP] Unable to open Bulletin "
